@@ -1,11 +1,8 @@
 from __future__ import absolute_import, unicode_literals
-import re
 import collections
 from django.conf import settings
 from django.db import connections
 from django.db.models import Model
-from django.db.models.manager import Manager
-from django.db.models.query import RawQuerySet
 
 from .. import smartsql
 from .signals import field_conversion
@@ -73,7 +70,7 @@ class QS(smartsql.QS):
         return super(QS, self).count()
 
     def iterator(self):
-        return self.execute().iterator()
+        return self.execute()
 
     def __iter__(self):
         """Returns iterator."""
@@ -225,94 +222,3 @@ def s(cls):
     return getattr(cls, a)
 
 setattr(Model, SMARTSQL_ALIAS, s)
-
-# TODO: Below is useless code for now. Remove it?
-
-# Fixing django.db.models.query.RawQuerySet,
-# because indexing and slicing are not performed at the database level
-# https://docs.djangoproject.com/en/dev/topics/db/sql/#index-lookups
-
-
-class PaginatedRawQuerySet(RawQuerySet):
-    """Extended RawQuerySet with pagination support"""
-
-    _cache = None
-
-    def count(self):
-        """Returns count of rows"""
-        sql = self.query.sql
-        if self._cache is not None:
-            return len(self._cache)
-        if not re.compile(r"""^((?:"(?:[^"\\]|\\"|\\\\)*"|'(?:[^'\\]|\\'|\\\\)*'|/\*.*?\*/|--[^\n]*\n|[^"'\\])+)(?:LIMIT|OFFSET).+$""", re.I | re.U | re.S).match(sql):
-            sql = re.compile(r"""^((?:"(?:[^"\\]|\\"|\\\\)*"|'(?:[^'\\]|\\'|\\\\)*'|/\*.*?\*/|--[^\n]*\n|[^"'\\])+)ORDER BY[^%]+$""", re.I | re.U | re.S).sub(r'\1', sql)
-        sql = "SELECT COUNT(1) as count_value FROM ({0}) as count_list".format(sql)
-        cursor = connections[self.query.using].cursor()
-        cursor.execute(sql, self.params)
-        row = cursor.fetchone()
-        return row[0]
-
-    def __len__(self):
-        """Returns count of rows"""
-        self.fill_cache()
-        return len(self._cache)
-
-    def __getitem__(self, k):
-        """Returns sliced instance of self.__class__"""
-        sql = self.query.sql
-        offset, limit = 0, None
-
-        if not isinstance(k, slice):
-            return list(self)[k]
-
-        if k.start is not None:
-            offset = int(k.start)
-        if k.stop is not None:
-            end = int(k.stop)
-            limit = end - offset
-        if limit:
-            sql = "{0} LIMIT {1:d}".format(sql, limit)
-        if offset:
-            sql = "{0} OFFSET {1:d}".format(sql, offset)
-        new_cls = self.__class__(
-            sql, model=self.model, query=None, params=self.params,
-            translations=self.translations, using=self.db
-        )
-        new_cls.sliced = True
-        new_cls.limit = limit
-        return new_cls
-
-    def fill_cache(self):
-        """Cache for small selections"""
-        if self._cache is None:
-            self._cache = list(self.iterator())
-        return self
-
-    def iterator(self):
-        return super(PaginatedRawQuerySet, self).__iter__()
-
-    def __iter__(self):
-        """Cache for small selections"""
-        self.fill_cache()
-        return iter(self._cache)
-
-    def using(self, alias):
-        """
-        Selects which database this Raw QuerySet should excecute it's query against.
-        """
-        return PaginatedRawQuerySet(
-            self.raw_query, model=self.model,
-            query=self.query.clone(using=alias),
-            params=self.params, translations=self.translations,
-            using=alias
-        )
-
-
-def raw(self, raw_query, params=None, *args, **kwargs):
-    return PaginatedRawQuerySet(raw_query=raw_query, model=self.model,
-                                params=params, using=self._db, *args, **kwargs)
-
-
-def patch_raw_query_set():
-    Manager.raw = raw
-
-patch_raw_query_set()
